From e84efa99e641797d7500ba26fbd0ddcfe2085cc4 Mon Sep 17 00:00:00 2001
From: Didier Raboud <odyx@debian.org>
Date: Sun, 1 Feb 2015 00:05:17 +0100
Subject: [PATCH 1/2] Use APT `apt-config dump`s result to determine where to
 find the system's sources.list

Closes: #775136
---
 build/util/gen-sources.list.udeb | 14 +++++++++++++-
 debian/changelog                 |  2 ++
 2 files changed, 15 insertions(+), 1 deletion(-)

diff --git a/build/util/gen-sources.list.udeb b/build/util/gen-sources.list.udeb
index 9f14010..dded88c 100755
--- a/build/util/gen-sources.list.udeb
+++ b/build/util/gen-sources.list.udeb
@@ -45,8 +45,20 @@ get_mirrors() {
 	done
 }
 
+# Cache the apt configuration dump, with only the needed namespace
+APT_CONFIG=$(apt-config dump | grep '^Dir::Etc')
+
+# Get the system apt directory
+APT_DIR_ETC=$(echo "$APT_CONFIG" | sed -n -e 's/^Dir::Etc *\"\(.*\)\";$/\1/p')
+
+# Fetch APT's sources.list
+APT_SOURCELIST=$(echo "$APT_CONFIG" | sed -n -e 's/^Dir::Etc::sourcelist *\"\(.*\)\";$/\1/p')
+
+# Fetch APT' sources.list.d
+APT_SOURCEPARTS=$(echo "$APT_CONFIG" | sed -n -e 's/^Dir::Etc::sourceparts *\"\(.*\)\";$/\1/p')
+
 # Also use mirrors defined in files in $SOURCES_LIST.d/
-MIRRORS="$(get_mirrors $SOURCES_LIST $SOURCES_LIST.d/*)"
+MIRRORS="$(get_mirrors $SOURCES_LIST /$APT_DIR_ETC/$APT_SOURCELIST /$APT_DIR_ETC/$APT_SOURCEPARTS)"
 
 if ! which 'wget' >/dev/null; then
 	echo "ERROR: the command wget is not available; please install it" >&2
diff --git a/debian/changelog b/debian/changelog
index 6390f2c..e8256cc 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -2,6 +2,8 @@ debian-installer (20150108) UNRELEASED; urgency=medium
 
   [ Didier Raboud ]
   * Correct typo and joy images paths in debian/copyright
+  * Use APT `apt-config dump`s result to determine where to find the
+    system's sources.list (Closes: #775136)
 
   [ Raphaël Hertzog ]
   * Bump Build-Depends on dns323-firmware-tools to require version
-- 
2.1.4

